==> knative-model-4.12.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelSpecBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaChannelSpecBuilder extends KafkaChannelSpecFluentImpl<KafkaChannelSpecBuilder> implements VisitableBuilder<KafkaChannelSpec,KafkaChannelSpecBuilder> {

    KafkaChannelSpecFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaChannelSpecBuilder() { 
        this(true);
    }


    public KafkaChannelSpecBuilder(Boolean validationEnabled) { 
        this(new KafkaChannelSpec(), validationEnabled);
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new KafkaChannelSpec(), validationEnabled);
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,KafkaChannelSpec instance) { 
        this(fluent, instance, true);
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,KafkaChannelSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withNumPartitions(instance.getNumPartitions()); 
        fluent.withReplicationFactor(instance.getReplicationFactor()); 
        fluent.withSubscribers(instance.getSubscribers()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpec instance) { 
        this(instance,true);
    }


    public KafkaChannelSpecBuilder(KafkaChannelSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withDelivery(instance.getDelivery()); 
        this.withNumPartitions(instance.getNumPartitions()); 
        this.withReplicationFactor(instance.getReplicationFactor()); 
        this.withSubscribers(instance.getSubscribers()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaChannelSpec build() {
        KafkaChannelSpec buildable = new KafkaChannelSpec(fluent.getDelivery(),fluent.getNumPartitions(),fluent.getReplicationFactor(),fluent.getSubscribers());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaChannelSpecBuilder that = (KafkaChannelSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.1.2-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelSpecBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaChannelSpecBuilder extends KafkaChannelSpecFluentImpl<KafkaChannelSpecBuilder> implements VisitableBuilder<KafkaChannelSpec,KafkaChannelSpecBuilder> {

    KafkaChannelSpecFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaChannelSpecBuilder() {
        this(true);
    }

    public KafkaChannelSpecBuilder(Boolean validationEnabled) {
        this(new KafkaChannelSpec(), validationEnabled);
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KafkaChannelSpec(), validationEnabled);
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,KafkaChannelSpec instance) {
        this(fluent, instance, true);
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpecFluent<?> fluent,KafkaChannelSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withDelivery(instance.getDelivery()); 
        fluent.withNumPartitions(instance.getNumPartitions()); 
        fluent.withReplicationFactor(instance.getReplicationFactor()); 
        fluent.withSubscribers(instance.getSubscribers()); 
        this.validationEnabled = validationEnabled; 
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpec instance) {
        this(instance,true);
    }

    public KafkaChannelSpecBuilder(KafkaChannelSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withDelivery(instance.getDelivery()); 
        this.withNumPartitions(instance.getNumPartitions()); 
        this.withReplicationFactor(instance.getReplicationFactor()); 
        this.withSubscribers(instance.getSubscribers()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.EditableKafkaChannelSpec build() {
        EditableKafkaChannelSpec buildable = new EditableKafkaChannelSpec(fluent.getDelivery(),fluent.getNumPartitions(),fluent.getReplicationFactor(),fluent.getSubscribers());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaChannelSpecBuilder that = (KafkaChannelSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
